==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/AreaFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FragmentBaseDescriptionMetadata } from "./FragmentBaseDescriptionMetadata";
import { AreaFragmentDescription } from "./AreaFragmentDescription";
/**
 * @hidden
 */
var AreaFragmentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AreaFragmentDescriptionMetadata, _super);
    function AreaFragmentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AreaFragmentDescriptionMetadata.b = function (a) {
        if (AreaFragmentDescriptionMetadata.a == null) {
            AreaFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AreaFragmentDescriptionMetadata.c(AreaFragmentDescriptionMetadata.a);
        }
        if (a.g(AreaFragmentDescriptionMetadata.a)) {
            return;
        }
        a.s(AreaFragmentDescriptionMetadata.a);
    };
    AreaFragmentDescriptionMetadata.c = function (a) {
        FragmentBaseDescriptionMetadata.c(a);
    };
    AreaFragmentDescriptionMetadata.d = function (a) {
        AreaFragmentDescriptionMetadata.b(a);
        a.u("AreaFragment", function () { return new AreaFragmentDescription(); });
        a.t("AreaFragment", AreaFragmentDescriptionMetadata.a);
    };
    AreaFragmentDescriptionMetadata.$t = markType(AreaFragmentDescriptionMetadata, 'AreaFragmentDescriptionMetadata');
    AreaFragmentDescriptionMetadata.a = null;
    return AreaFragmentDescriptionMetadata;
}(Base));
export { AreaFragmentDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/AreaFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FragmentBaseDescriptionMetadata } from "./FragmentBaseDescriptionMetadata";
import { AreaFragmentDescription } from "./AreaFragmentDescription";
/**
 * @hidden
 */
var AreaFragmentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AreaFragmentDescriptionMetadata, _super);
    function AreaFragmentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AreaFragmentDescriptionMetadata.b = function (a) {
        if (AreaFragmentDescriptionMetadata.a == null) {
            AreaFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AreaFragmentDescriptionMetadata.c(AreaFragmentDescriptionMetadata.a);
        }
        if (a.j(AreaFragmentDescriptionMetadata.a)) {
            return;
        }
        a.y(AreaFragmentDescriptionMetadata.a);
    };
    AreaFragmentDescriptionMetadata.c = function (a) {
        FragmentBaseDescriptionMetadata.c(a);
    };
    AreaFragmentDescriptionMetadata.d = function (a) {
        AreaFragmentDescriptionMetadata.b(a);
        a.aa("AreaFragment", function () { return new AreaFragmentDescription(); });
        a.z("AreaFragment", AreaFragmentDescriptionMetadata.a);
    };
    AreaFragmentDescriptionMetadata.$t = markType(AreaFragmentDescriptionMetadata, 'AreaFragmentDescriptionMetadata');
    AreaFragmentDescriptionMetadata.a = null;
    return AreaFragmentDescriptionMetadata;
}(Base));
export { AreaFragmentDescriptionMetadata };
